==> jc-1.4.0.tar.gz: javax/naming/BinaryRefAddr.h <==
// public class javax.naming.BinaryRefAddr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2702790b04fcc676 javax_naming_BinaryRefAddr
// @dep_class 1aa52b9631354f18 javax_naming_RefAddr

// header file dependencies
// @dep_header javax_naming_RefAddr

#include "javax/naming/RefAddr.h"

#ifndef _JC_javax_naming_BinaryRefAddr_H_
#define _JC_javax_naming_BinaryRefAddr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_naming_BinaryRefAddr$sub_refs	_jc_javax_naming_BinaryRefAddr$sub_refs;
typedef struct _jc_javax_naming_BinaryRefAddr$sub_nonrefs	_jc_javax_naming_BinaryRefAddr$sub_nonrefs;
typedef struct _jc_javax_naming_BinaryRefAddr$refs	_jc_javax_naming_BinaryRefAddr$refs;
typedef struct _jc_javax_naming_BinaryRefAddr$nonrefs	_jc_javax_naming_BinaryRefAddr$nonrefs;
typedef struct _jc_javax_naming_BinaryRefAddr$object	_jc_javax_naming_BinaryRefAddr$object;

typedef struct _jc_javax_naming_BinaryRefAddr$fields_struct	_jc_javax_naming_BinaryRefAddr$fields_struct;
typedef const struct _jc_javax_naming_BinaryRefAddr$vmethods	_jc_javax_naming_BinaryRefAddr$vmethods;
typedef const struct _jc_javax_naming_BinaryRefAddr$vtable	_jc_javax_naming_BinaryRefAddr$vtable;
typedef const struct _jc_javax_naming_BinaryRefAddr$vtype	_jc_javax_naming_BinaryRefAddr$vtype;

// Class fields structure
struct _jc_javax_naming_BinaryRefAddr$fields_struct {
	_jc_char_array	*hex;
	jlong	serialVersionUID;
};
extern _jc_javax_naming_BinaryRefAddr$fields_struct _jc_javax_naming_BinaryRefAddr$class_fields;

// Constructors
extern void _jc_javax_naming_BinaryRefAddr$method$_init$8978305ea064370f(_jc_env *, struct _jc_javax_naming_BinaryRefAddr$object *, struct _jc_java_lang_String$object *, struct _jc_byte_array *);
extern void _jc_javax_naming_BinaryRefAddr$method$_init$74e825b4be7314c5(_jc_env *, struct _jc_javax_naming_BinaryRefAddr$object *, struct _jc_java_lang_String$object *, struct _jc_byte_array *, jint, jint);

// Virtual methods
extern jboolean _jc_javax_naming_BinaryRefAddr$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_naming_BinaryRefAddr$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_javax_naming_BinaryRefAddr$method$getContent$3271597a0076ff68(_jc_env *, struct _jc_javax_naming_BinaryRefAddr$object *);
extern jint _jc_javax_naming_BinaryRefAddr$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_naming_BinaryRefAddr$object *);
extern struct _jc_java_lang_String$object *_jc_javax_naming_BinaryRefAddr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_naming_BinaryRefAddr$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_naming_BinaryRefAddr$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_naming_BinaryRefAddr$method_info$getContent$3271597a0076ff68;
extern _jc_method _jc_javax_naming_BinaryRefAddr$method_info$hashCode$53152098849316df;
extern _jc_method _jc_javax_naming_BinaryRefAddr$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_javax_naming_BinaryRefAddr$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_javax_naming_BinaryRefAddr$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_naming_BinaryRefAddr$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*getContent$3271597a0076ff68)(_jc_env *, struct _jc_javax_naming_BinaryRefAddr$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_naming_BinaryRefAddr$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_naming_BinaryRefAddr$object *);
};

// Vtable
struct _jc_javax_naming_BinaryRefAddr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_RefAddr$vmethods	javax_naming_RefAddr;
	_jc_javax_naming_BinaryRefAddr$vmethods	javax_naming_BinaryRefAddr;
};

// Vtype
struct _jc_javax_naming_BinaryRefAddr$vtype {
	_jc_type			type;
	_jc_javax_naming_BinaryRefAddr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_BinaryRefAddr$sub_refs {
	_jc_byte_array	*buf;
};

// Reference instance fields (object)
struct _jc_javax_naming_BinaryRefAddr$refs {
    _jc_javax_naming_BinaryRefAddr$sub_refs	javax_naming_BinaryRefAddr;
    _jc_javax_naming_RefAddr$sub_refs	javax_naming_RefAddr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_BinaryRefAddr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_BinaryRefAddr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_RefAddr$sub_nonrefs	javax_naming_RefAddr;
    _jc_javax_naming_BinaryRefAddr$sub_nonrefs	javax_naming_BinaryRefAddr;
};

// Object instance structure
struct _jc_javax_naming_BinaryRefAddr$object {
	_jc_javax_naming_BinaryRefAddr$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_BinaryRefAddr$vtype	*vtype;
	_jc_javax_naming_BinaryRefAddr$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_BinaryRefAddr$vtype _jc_javax_naming_BinaryRefAddr$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_BinaryRefAddr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_BinaryRefAddr$class_object;

#endif	/* _JC_javax_naming_BinaryRefAddr_H_ */

==> jc-1.4.6.tar.gz: javax/naming/BinaryRefAddr.h <==
// public class javax.naming.BinaryRefAddr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2702790b04fcc676 javax_naming_BinaryRefAddr
// @dep_class 1aa52b9631354f18 javax_naming_RefAddr

// header file dependencies
// @dep_header javax_naming_RefAddr

#include "javax/naming/RefAddr.h"

#ifndef _JC_javax_naming_BinaryRefAddr_H_
#define _JC_javax_naming_BinaryRefAddr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_naming_BinaryRefAddr$sub_refs	_jc_javax_naming_BinaryRefAddr$sub_refs;
typedef struct _jc_javax_naming_BinaryRefAddr$sub_nonrefs	_jc_javax_naming_BinaryRefAddr$sub_nonrefs;
typedef struct _jc_javax_naming_BinaryRefAddr$refs	_jc_javax_naming_BinaryRefAddr$refs;
typedef struct _jc_javax_naming_BinaryRefAddr$nonrefs	_jc_javax_naming_BinaryRefAddr$nonrefs;
typedef struct _jc_javax_naming_BinaryRefAddr$object	_jc_javax_naming_BinaryRefAddr$object;

typedef struct _jc_javax_naming_BinaryRefAddr$fields_struct	_jc_javax_naming_BinaryRefAddr$fields_struct;
typedef const struct _jc_javax_naming_BinaryRefAddr$vmethods	_jc_javax_naming_BinaryRefAddr$vmethods;
typedef const struct _jc_javax_naming_BinaryRefAddr$vtable	_jc_javax_naming_BinaryRefAddr$vtable;
typedef const struct _jc_javax_naming_BinaryRefAddr$vtype	_jc_javax_naming_BinaryRefAddr$vtype;

// Class fields structure
struct _jc_javax_naming_BinaryRefAddr$fields_struct {
	_jc_char_array	*hex;
	jlong	serialVersionUID;
};
extern _jc_javax_naming_BinaryRefAddr$fields_struct _jc_javax_naming_BinaryRefAddr$class_fields;

// Constructors
extern void _jc_javax_naming_BinaryRefAddr$method$_init$8978305ea064370f(_jc_env *, struct _jc_javax_naming_BinaryRefAddr$object *, struct _jc_java_lang_String$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_javax_naming_BinaryRefAddr$method$_init$74e825b4be7314c5(_jc_env *, struct _jc_javax_naming_BinaryRefAddr$object *, struct _jc_java_lang_String$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_naming_BinaryRefAddr$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_naming_BinaryRefAddr$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_javax_naming_BinaryRefAddr$method$getContent$3271597a0076ff68(_jc_env *, struct _jc_javax_naming_BinaryRefAddr$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_naming_BinaryRefAddr$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_naming_BinaryRefAddr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_naming_BinaryRefAddr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_naming_BinaryRefAddr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_naming_BinaryRefAddr$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_naming_BinaryRefAddr$method_info$getContent$3271597a0076ff68;
extern _jc_method _jc_javax_naming_BinaryRefAddr$method_info$hashCode$53152098849316df;
extern _jc_method _jc_javax_naming_BinaryRefAddr$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_javax_naming_BinaryRefAddr$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_naming_BinaryRefAddr$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_naming_BinaryRefAddr$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getContent$3271597a0076ff68)(_jc_env *, struct _jc_javax_naming_BinaryRefAddr$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_naming_BinaryRefAddr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_naming_BinaryRefAddr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_naming_BinaryRefAddr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_RefAddr$vmethods	javax_naming_RefAddr;
	_jc_javax_naming_BinaryRefAddr$vmethods	javax_naming_BinaryRefAddr;
};

// Vtype
struct _jc_javax_naming_BinaryRefAddr$vtype {
	_jc_type			type;
	_jc_javax_naming_BinaryRefAddr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_BinaryRefAddr$sub_refs {
	_jc_byte_array	*buf;
};

// Reference instance fields (object)
struct _jc_javax_naming_BinaryRefAddr$refs {
    _jc_javax_naming_BinaryRefAddr$sub_refs	javax_naming_BinaryRefAddr;
    _jc_javax_naming_RefAddr$sub_refs	javax_naming_RefAddr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_BinaryRefAddr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_BinaryRefAddr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_RefAddr$sub_nonrefs	javax_naming_RefAddr;
    _jc_javax_naming_BinaryRefAddr$sub_nonrefs	javax_naming_BinaryRefAddr;
};

// Object instance structure
struct _jc_javax_naming_BinaryRefAddr$object {
	_jc_javax_naming_BinaryRefAddr$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_BinaryRefAddr$vtype	*vtype;
	_jc_javax_naming_BinaryRefAddr$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_BinaryRefAddr$vtype _jc_javax_naming_BinaryRefAddr$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_BinaryRefAddr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_BinaryRefAddr$class_object;

#endif	/* _JC_javax_naming_BinaryRefAddr_H_ */
